@@ -1,9 +1,12 @@
+""" Main interface to the CLI.
+"""
+
 import click
 
 from grade.cli import run, report
 
 
-@click.group()
+@click.group(name="grade")
 def cli():
     pass
 
@@ -12,4 +15,4 @@ cli.add_command(run.run)
 cli.add_command(report.report)
 
 if __name__ == "__main__":
-    cli()
+    cli(prog_name="grade")
