@@ -1,3 +1,8 @@
+""" Run.
+
+Handles running the test suite and saving results.
+"""
+
 import json
 import unittest
 
@@ -6,11 +11,10 @@ import click
 from grade.runners import GradedRunner
 
 
-@click.command()
-@click.option("--batch/--single", default=False)
-@click.option("--context", default=".")
-@click.option("-p", "--pattern", default="test*")
-def run(batch, context, pattern):
+@click.command(short_help="runs the test suite")
+@click.option("--context", default=".", help="context to run tests from")
+@click.option("-p", "--pattern", default="test*", help="pattern to find files with")
+def run(context, pattern):
     """ Run the autograder. """
     suite = unittest.defaultTestLoader.discover(context, pattern=pattern)
     results = GradedRunner(visibility="visible").run(suite)
