@@ -19,7 +19,9 @@ class GradedRunner(TextTestRunner):
         tb_locals: bool = False,
         visibility: "str" = "visible",
     ) -> None:
-        super().__init__(stream, descriptions, verbosity, failfast, buffer, Result, warnings, tb_locals=tb_locals)
+        super().__init__(
+            stream, descriptions, verbosity, failfast, buffer, Result, warnings, tb_locals=tb_locals
+        )
         self.visibility = visibility
 
     def run(self, test) -> Result:
@@ -37,7 +39,7 @@ class GradedRunner(TextTestRunner):
                     "name": t.__qualname__,
                     "max_score": 0,
                     "score": "0",
-                    "output": ";\n".join([f"{e[0]}: {e[1]}" for e in results.errors]),
+                    "output": ";\n".join(f"{e[0]}: {e[1]}" for e in results.errors),
                 }
                 for k, t in tests
             ]
